pub enum ExtractorMode {
Raw,
Token(usize),
}Expand description
Defines the way embeddings are extracted from the output tensor
Variants
Raw
The tensor is expected to provide directly usable embeddings for each sequence
Token(usize)
The tensor is expected to provide embeddings for each token, and we use one’s vector as sequence embedding (usually the first one)