pub struct EmbeddingsExtractor { /* private fields */ }Expand description
Composable that extracts the embeddings from the output tensors, according to the specified output id and extraction mode
Implementations
Sourceimpl EmbeddingsExtractor
impl EmbeddingsExtractor
pub fn new(output_id: &OutputId, mode: ExtractorMode) -> Self